"""Basic moving living thing in-game"""

import entity, vector, ragdoll

import pygame

import os.path

class Character(entity.Entity):
    """contains all game mechanics methods except for physics, handled by ragdoll"""
    def __init__(self, game, image, moves):
        pygame.sprite.Sprite.__init__(self)
        self.color = pygame.Color(0)
        self.ragdoll = ragdoll.Ragdoll(self.color, image, os.path.normcase(os.path.normpath(moves)))
        self.image = self.ragdoll.get_image()
        self.rect = self.image.get_rect()
        self.game = game
        self.termvel = 63
        self.vector = vector.Vec2d(0, 0)
        self.vectors = {}
        self.add_vector("grav", (0, self.game.level.grav))
        
    def update(self):
        entity.Entity.update(self)
        
    def collidecheck(self, newpos):
        top = self.game.level.get_at(newpos.centerx, newpos.top)
        if top and top.solid == "true":
            newpos.top = top.rect.bottom
            for vec in self.vectors.values(): # if you hit top while jumping, fall
                if vec.y < 0:
                    vec.y = 0
            self.vectors["grav"] = vector.Vec2d(0, self.game.level.grav)
        bottom = self.game.level.get_at(newpos.centerx, newpos.bottom)
        if bottom and bottom.solid == "true":
            newpos.bottom = bottom.rect.top
        right1 = self.game.level.get_at(newpos.right, newpos.centery-(self.rect.height/4))
        if right1 and right1.solid == "true":
            newpos.right = right1.rect.left
        right2 = self.game.level.get_at(newpos.right, newpos.centery+(self.rect.height/4))
        if right2 and right2.solid == "true":
            newpos.right = right2.rect.left
        left1 = self.game.level.get_at(newpos.left, newpos.centery-(self.rect.height/4))
        if left1 and left1.solid == "true":
            newpos.left = left1.rect.right
        left2 = self.game.level.get_at(newpos.left, newpos.centery+(self.rect.height/4))
        if left2 and left2.solid == "true":
            newpos.left = left2.rect.right
        
        return newpos
        
    def set_color(self, color):
        self.color = pygame.Color(color)
