"""Limb class, use with ragdoll"""

import pygame

import math

class Limb:
    """a vector that auto rotates to a specific angle"""
    def __init__(self, p1, p2, maxspeed, color, target):
        self.p1 = p1
        self.p2 = p2
        self.diff = [p1[0]-p2[0], p1[1]-p2[1]]
        self.color = pygame.Color(color)
        self.target = target
        self.maxspeed = maxspeed
        self.p2limbs = []
        self.p1limbs = []
        
    def update(self):
        diff = self.target - self.get_angle()
        if abs(diff) > self.maxspeed:
            diff = self.maxspeed * math.copysign(1, diff)
        self.rotate(diff)
        
        for limb in self.p1limbs:
            limb.p1 = self.p1
            limb.update()
        for limb in self.p2limbs:
            limb.p1 = self.p2
            limb.update()
            
    def draw(self, image):
        pygame.draw.aaline(image, self.color, (self.p1[0] , self.p1[1]), (self.p2[0], self.p2[1]))
            
    def rotate(self, radians): #pulled and modified from Vec2d in pygame cookbook
        cos = math.cos(radians)
        sin = math.sin(radians)
        x = self.diff[0]*cos - self.diff[1]*sin
        y = self.diff[0]*sin + self.diff[1]*cos
        self.diff[0] = x
        self.diff[1] = y
        self.p2[0], self.p2[1] = self.p1[0]+self.diff[0], self.p1[1]+self.diff[1]
        
    def get_angle(self):
        return math.atan2(self.diff[1], self.diff[0])
    
    def set_color(self, color):
        self.color = pygame.Color(color)
