"""Game object, contains all basic game code."""

import pygame
from pygame.locals import *
import level, entity, controller, camera

class Game(pygame.sprite.Group):
    """Overarching game class, contains loop, input handling, and data management"""
    def __init__(self, screen):
        pygame.sprite.Group.__init__(self)
        self.screen = screen
        self.level = level.Level("res/lev/Air-1.level")
        self.controller = controller.Controller(["w", "a", "s", "d", "r", "space"])
        self.enemies = pygame.sprite.Group()
        self.clock = pygame.time.Clock()
        self.cam = camera.Camera(self.level, self)
        self.running = True
        
    def get_input(self):
        """run through the event queue and distribute events accordingly"""
        for e in pygame.event.get():
            if e.type == QUIT:
                self.running = False
            elif e.type == KEYDOWN:
                if pygame.key.name(e.key) in self.controller.keys.keys():
                    self.controller.keys[pygame.key.name(e.key)] = True
            elif e.type == KEYUP:
                if pygame.key.name(e.key) in self.controller.keys.keys():
                    self.controller.keys[pygame.key.name(e.key)] = False
            elif e.type == MOUSEBUTTONDOWN:
                if e.button == 1: self.controller.mouse[1] = True
                if e.button == 3: self.controller.mouse[3] = True
            elif e.type == MOUSEBUTTONUP:
                if e.button == 1: self.controller.mouse[1] = False
                if e.button == 3: self.controller.mouse[3] = False
                
        self.controller.mouse["pos"] = pygame.mouse.get_pos()
        
    def update(self):
        self.level.update()
        pygame.sprite.Group.update(self)
        
    def run(self):
        self.spawn()
        while self.running:
            self.get_input()
            self.update()
            self.cam.draw()
            pygame.display.flip()
            self.clock.tick(30)
            
    def spawn(self):
        player = entity.Player(self, self.controller)
        player.rect.topleft = self.level.find_tag("spawnp")
        self.add(player)
        
    def get_player(self):
        for sprite in self.sprites():
            if isinstance(sprite, entity.Player):
                return sprite
        
